@@ -1,6 +1,6 @@
 /* wayV - NGUI (Next Generation User Interfaces)
  *
- * Copyright (C) 2000-2001 Mike Bennett (smoog@stressbunny.com)
+ * Copyright (C) 2000-2003 Mike Bennett (smoog at stressbunny dot com)
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,4 +34,4 @@ WGESTURE *findGesture(WSETUP *, MATRIX *, VECTOR *, char *);
 int pointDensityAnalysis(MATRIX *, MATRIX *);
 int vectCmp(VECTOR *, VECTOR *);
 
-#endif __AI_H__
+#endif /* __AI_H__ */
