@@ -1,6 +1,6 @@
 /* wayV - NGUI (Next Generation User Interfaces)
  *
- * Copyright (C) 2000-2001 Mike Bennett (smoog@stressbunny.com)
+ * Copyright (C) 2000-2003 Mike Bennett (smoog at stressbunny dot com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,4 +27,4 @@
 
 void waitMilli(long int);
 
-#endif __MISC_H__
+#endif /* __MISC_H__ */
