@@ -1,6 +1,6 @@
 /* wayV - NGUI (Next Generation User Interfaces)
  *
- * Copyright (C) 2000-2001 Mike Bennett (smoog@stressbunny.com)
+ * Copyright (C) 2000-2003 Mike Bennett (smoog at stressbunny dot com)
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  * 
  * Purpose:
- *		Header for process.c
+ *	Header for process.c
 */
 
 #ifndef __PROCESS_H__
@@ -35,4 +35,4 @@ char **createCmdLine(char *, GDISPLAY *, GPOINT *);
 void setupSignals();
 void destroyZombies(int);
 
-#endif __PROCESS_H__
+#endif /* __PROCESS_H__ */
