@@ -1,6 +1,6 @@
 /* wayV - NGUI (Next Generation User Interfaces)
  * 
- * Copyright (C) 2000-2001 Mike Bennett (smoog@stressbunny.com)
+ * Copyright (C) 2000-2003 Mike Bennett (smoog at stressbunny dot com)
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
 #include<stdio.h>
 #include<stdlib.h>
 #include<string.h>
+#include<ctype.h>
 #include "defines.h"
 #include "setup.h"
 #include "gesture.h"
@@ -201,6 +202,7 @@ WSETUP *processSetup(WSETUP *wayv) {
  *	19/04/2001 (Mike Bennett): Report an error if cannot find the 
  *				   configuration file and updated to look in
  *				   the right place for the keymap
+ *	08/04/2003 (Nick Rusnov): Allow any mouse button to be used to activate
  *
  * Notes:
  *	When the parser is rewritten make sure and setup everything with
@@ -335,17 +337,8 @@ WSETUP *parseSetup(WSETUP *wayv, char *fileName) {
 				wayv->launch->method = getKeyText(setup, &i, SKT_QUOTES);
 
 				for(n = 0; (temp = getCommaText(wayv->launch->method, &n)) != NULL;) {
-					if(strcmp(temp, "M1") == 0)
-						wayv->launch->pbutton = PBUTTON1;
-					else if(strcmp(temp, "M2") == 0)
-						wayv->launch->pbutton = PBUTTON2;
-					else if(strcmp(temp, "M3") == 0)
-						wayv->launch->pbutton = PBUTTON3;
-					else if(strcmp(temp, "M4") == 0)
-						wayv->launch->pbutton = PBUTTON4;
-					else if(strcmp(temp, "M5") == 0)
-						wayv->launch->pbutton = PBUTTON5;
-
+					if((strlen(temp) >= 2) && (temp[0] == 'M') && (isdigit(temp[1])))
+				       		wayv->launch->pbutton = atoi(&temp[1]);
 					else if(strcmp(temp, "SHIFT") == 0)
 						wayv->launch->kmodifier |= KMODSHIFT;
 					else if(strcmp(temp, "LOCK") == 0)
